"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var plantUmlEncoder = require("plantuml-encoder");
/**
 * Class for creating URLs to local, embedded or remote PlantUML diagram images.
 */
var ImageUrlGenerator = /** @class */ (function () {
    function ImageUrlGenerator() {
    }
    /**
     * Creates a URL to a local image file.
     * @param pageFilePath Path of the page that is referencing the image.
     * @param imageFilePath Path to the local image file.
     * @returns The URL to the local image file.
     */
    ImageUrlGenerator.prototype.createLocalImageFileUrl = function (pageFilePath, imageFilePath) {
        var pageFileDir = path.dirname(pageFilePath);
        return path.relative(pageFileDir, imageFilePath);
    };
    /**
     * Creates a URL for an embedded image.
     * @param imageData The data of the image.
     * @param imageFormat The format of the image data.
     * @returns The URL for the embedded image.
     */
    ImageUrlGenerator.prototype.createEmbeddedImageUrl = function (imageData, imageFormat) {
        var mimeType = imageFormat === "png" ? "image/png" : "image/svg+xml";
        return "data:" + mimeType + ";base64," + imageData.toString("base64");
    };
    /**
     * Creates a PlantUML server URL that generates an image.
     * @param plantUmlCode The PlantUML code for the image.
     * @param imageFormat The format for the image.
     * @returns The PlantUML server URL for the image.
     */
    ImageUrlGenerator.prototype.createPlantUmlServerUrl = function (plantUmlCode, imageFormat) {
        var encodedPlantUml = plantUmlEncoder.encode(plantUmlCode);
        return "http://www.plantuml.com/plantuml/" + imageFormat + "/" + encodedPlantUml;
    };
    return ImageUrlGenerator;
}());
exports.ImageUrlGenerator = ImageUrlGenerator;
