"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var typedoc_1 = require("typedoc");
var enumerations_1 = require("./enumerations");
/**
 * Supported image output locations.
 */
var ImageLocation;
(function (ImageLocation) {
    ImageLocation[ImageLocation["Local"] = 1] = "Local";
    ImageLocation[ImageLocation["Remote"] = 2] = "Remote";
    ImageLocation[ImageLocation["Embed"] = 3] = "Embed";
})(ImageLocation = exports.ImageLocation || (exports.ImageLocation = {}));
/**
 * Supported class diagram positions.
 */
var ClassDiagramPosition;
(function (ClassDiagramPosition) {
    ClassDiagramPosition[ClassDiagramPosition["Above"] = 1] = "Above";
    ClassDiagramPosition[ClassDiagramPosition["Below"] = 2] = "Below";
})(ClassDiagramPosition = exports.ClassDiagramPosition || (exports.ClassDiagramPosition = {}));
/**
 * Class storing the options of the plugin.
 */
var PluginOptions = /** @class */ (function () {
    function PluginOptions() {
        /** Specifies how detailed the class diagrams should be. */
        this.classDiagramTypeOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramType",
            help: "none|simple|detailed",
            defaultValue: enumerations_1.ClassDiagramType.Detailed,
            map: new Map([
                ["none", enumerations_1.ClassDiagramType.None],
                ["simple", enumerations_1.ClassDiagramType.Simple],
                ["detailed", enumerations_1.ClassDiagramType.Detailed],
            ]),
            value: enumerations_1.ClassDiagramType.Detailed,
        };
        /** The location where the class diagrams should be stored. */
        this.outputImageLocationOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramLocation",
            help: "local|remote|embed",
            defaultValue: ImageLocation.Local,
            map: new Map([
                ["local", ImageLocation.Local],
                ["remote", ImageLocation.Remote],
                ["embed", ImageLocation.Embed],
            ]),
            value: ImageLocation.Local,
        };
        /** The image format used for the class diagrams. */
        this.outputImageFormatOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramFormat",
            help: "png|svg",
            defaultValue: "svg" /* SVG */,
            map: new Map([
                ["png", "png" /* PNG */],
                ["svg", "svg" /* SVG */],
            ]),
            value: "svg" /* SVG */,
        };
        /** Specifies the background color used for boxes in the class diagrams. */
        this.sectionTitleOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramSectionTitle",
            help: "The title of the section on the page which includes the class diagram.",
            defaultValue: "Hierarchy-Diagram",
            value: "Hierarchy-Diagram",
        };
        /** Specifies where on the page the class diagram should be put. */
        this.classDiagramPositionOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramPosition",
            help: "above|below",
            defaultValue: ClassDiagramPosition.Above,
            map: new Map([
                ["above", ClassDiagramPosition.Above],
                ["below", ClassDiagramPosition.Below],
            ]),
            value: ClassDiagramPosition.Above,
        };
        /** Specifies how method parameters should be output in the class diagrams. */
        this.classDiagramMethodParameterOutputOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramMethodParameterOutput",
            help: "none|only-names|only-types|complete",
            defaultValue: enumerations_1.MethodParameterOutput.Complete,
            map: new Map([
                ["none", enumerations_1.MethodParameterOutput.None],
                ["only-names", enumerations_1.MethodParameterOutput.OnlyNames],
                ["only-types", enumerations_1.MethodParameterOutput.OnlyTypes],
                ["complete", enumerations_1.MethodParameterOutput.Complete],
            ]),
            value: enumerations_1.MethodParameterOutput.Complete,
        };
        /** Specifies whether to hide empty properties and methods in the class diagrams. */
        this.classDiagramHideEmptyMembersOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideEmptyMembers",
            help: "true|false",
            defaultValue: true,
            value: true,
        };
        /** Specifies the boundary before swiching from top->down to left->right direction for class diagrams. */
        this.classDiagramTopDownLayoutMaxSiblingsOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramTopDownLayoutMaxSiblings",
            help: "An integer indicating the max number of siblings to be used with the default top down layout.",
            defaultValue: 6,
            minValue: 0,
            value: 6,
        };
        /** Specifies how the visibility of members should be displayed in the class diagrams. */
        this.classDiagramMemberVisibilityStyleOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramMemberVisibilityStyle",
            help: "text|icon",
            defaultValue: enumerations_1.ClassDiagramMemberVisibilityStyle.Icon,
            map: new Map([
                ["text", enumerations_1.ClassDiagramMemberVisibilityStyle.Text],
                ["icon", enumerations_1.ClassDiagramMemberVisibilityStyle.Icon],
            ]),
            value: enumerations_1.ClassDiagramMemberVisibilityStyle.Icon,
        };
        /**
         * Specifies whether to hide the circled character in front of class names in the class diagrams.
         */
        this.classDiagramHideCircledCharOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideCircledChar",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
        /** Specifies whether to hide the shadowing in the class diagrams. */
        this.classDiagramHideShadowOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideShadow",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
        /** Specifies the background color used for boxes in the class diagrams. */
        this.classDiagramBoxBackgroundColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramBoxBackgroundColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the border color used for boxes in the class diagrams. */
        this.classDiagramBoxBorderColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramBoxBorderColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the border radius used for boxes in the class diagrams. */
        this.classDiagramBoxBorderRadiusOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramBoxBorderRadius",
            help: "The box border radius in pixel used for the class diagrams.",
            defaultValue: 0,
            minValue: 0,
            value: 0,
        };
        /** Specifies the border width used for boxes in the class diagrams. */
        this.classDiagramBoxBorderWidthOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramBoxBorderWidth",
            help: "The box border width in pixel used for the class diagrams.",
            defaultValue: -1,
            minValue: 0,
            value: -1,
        };
        /** Specifies the color used for arrows in the class diagrams. */
        this.classDiagramArrowColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramArrowColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the name of the font used for the class name in the class diagrams. */
        this.classDiagramClassFontNameOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassFontName",
            help: "The name of the font used for the class name in the class diagrams.",
            defaultValue: "",
            value: "",
        };
        /** Specifies the font size for the class name in the class diagrams. */
        this.classDiagramClassFontSizeOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramClassFontSize",
            help: "The font size in pixel used for the class name in the class diagrams.",
            defaultValue: 0,
            minValue: 0,
            value: 0,
        };
        /** Specifies the font style for the class name in the class diagrams. */
        this.classDiagramClassFontStyleOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramClassFontStyle",
            help: "normal|plain|italic|bold",
            defaultValue: "" /* Undefined */,
            map: new Map([
                ["normal", "normal" /* Normal */],
                ["plain", "plain" /* Plain */],
                ["italic", "italic" /* Italic */],
                ["bold", "bold" /* Bold */],
            ]),
            value: "" /* Undefined */,
        };
        /** Specifies the font color for the class name in the class diagrams. */
        this.classDiagramClassFontColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassFontColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies the name of the font used for the class attributes in the class diagrams. */
        this.classDiagramClassAttributeFontNameOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassAttributeFontName",
            help: "The name of the font used for the class attributes in the class diagrams.",
            defaultValue: "",
            value: "",
        };
        /** Specifies the font size for the class attributes in the class diagrams. */
        this.classDiagramClassAttributeFontSizeOption = {
            type: typedoc_1.ParameterType.Number,
            name: "umlClassDiagramClassAttributeFontSize",
            help: "The font size in pixel used for the class attributes in the class diagrams.",
            defaultValue: 0,
            minValue: 0,
            value: 0,
        };
        /** Specifies the font style for the class attributes in the class diagrams. */
        this.classDiagramClassAttributeFontStyleOption = {
            type: typedoc_1.ParameterType.Map,
            name: "umlClassDiagramClassAttributeFontStyle",
            help: "normal|plain|italic|bold",
            defaultValue: "" /* Undefined */,
            map: new Map([
                ["normal", "normal" /* Normal */],
                ["plain", "plain" /* Plain */],
                ["italic", "italic" /* Italic */],
                ["bold", "bold" /* Bold */],
            ]),
            value: "" /* Undefined */,
        };
        /** Specifies the font color for the class attributes in the class diagrams. */
        this.classDiagramClassAttributeFontColorOption = {
            type: typedoc_1.ParameterType.String,
            name: "umlClassDiagramClassAttributeFontColor",
            help: "transparent|#RGBHEX",
            defaultValue: "",
            value: "",
        };
        /** Specifies whether to hide the progress bar while generating diagrams. */
        this.hideProgressBarOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramHideProgressBar",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
        /** Specifies whether to create files containing the PlantUML code of the class diagrams. */
        this.createPlantUmlFilesOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramCreatePlantUmlFiles",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
        /** Specifies whether the plugin should output verbose info during its work. */
        this.createVerboseOutputOption = {
            type: typedoc_1.ParameterType.Boolean,
            name: "umlClassDiagramVerboseOutput",
            help: "true|false",
            defaultValue: false,
            value: false,
        };
    }
    /**
     * Adds the command line options of the plugin to the TypeDoc application.
     * @param typedoc The TypeDoc application.
     */
    // prettier-ignore
    PluginOptions.prototype.addToApplication = function (typedoc) {
        typedoc.options.addDeclaration(this.classDiagramTypeOption);
        typedoc.options.addDeclaration(this.outputImageLocationOption);
        typedoc.options.addDeclaration(this.outputImageFormatOption);
        typedoc.options.addDeclaration(this.sectionTitleOption);
        typedoc.options.addDeclaration(this.classDiagramPositionOption);
        typedoc.options.addDeclaration(this.classDiagramMethodParameterOutputOption);
        typedoc.options.addDeclaration(this.classDiagramHideEmptyMembersOption);
        typedoc.options.addDeclaration(this.classDiagramTopDownLayoutMaxSiblingsOption);
        typedoc.options.addDeclaration(this.classDiagramMemberVisibilityStyleOption);
        typedoc.options.addDeclaration(this.classDiagramHideCircledCharOption);
        typedoc.options.addDeclaration(this.classDiagramHideShadowOption);
        typedoc.options.addDeclaration(this.classDiagramBoxBackgroundColorOption);
        typedoc.options.addDeclaration(this.classDiagramBoxBorderColorOption);
        typedoc.options.addDeclaration(this.classDiagramBoxBorderRadiusOption);
        typedoc.options.addDeclaration(this.classDiagramBoxBorderWidthOption);
        typedoc.options.addDeclaration(this.classDiagramArrowColorOption);
        typedoc.options.addDeclaration(this.classDiagramClassFontNameOption);
        typedoc.options.addDeclaration(this.classDiagramClassFontSizeOption);
        typedoc.options.addDeclaration(this.classDiagramClassFontStyleOption);
        typedoc.options.addDeclaration(this.classDiagramClassFontColorOption);
        typedoc.options.addDeclaration(this.classDiagramClassAttributeFontNameOption);
        typedoc.options.addDeclaration(this.classDiagramClassAttributeFontSizeOption);
        typedoc.options.addDeclaration(this.classDiagramClassAttributeFontStyleOption);
        typedoc.options.addDeclaration(this.classDiagramClassAttributeFontColorOption);
        typedoc.options.addDeclaration(this.hideProgressBarOption);
        typedoc.options.addDeclaration(this.createPlantUmlFilesOption);
        typedoc.options.addDeclaration(this.createVerboseOutputOption);
    };
    /**
     * Reads the values of the plugin options from the application options.
     * @param appOptions The TypeDoc application.
     */
    // prettier-ignore
    PluginOptions.prototype.readValuesFromApplication = function (typedoc) {
        this.classDiagramTypeOption.value = typedoc.options.getValue(this.classDiagramTypeOption.name);
        this.outputImageLocationOption.value = typedoc.options.getValue(this.outputImageLocationOption.name);
        this.outputImageFormatOption.value = typedoc.options.getValue(this.outputImageFormatOption.name);
        this.sectionTitleOption.value = typedoc.options.getValue(this.sectionTitleOption.name);
        this.classDiagramPositionOption.value = typedoc.options.getValue(this.classDiagramPositionOption.name);
        this.classDiagramMethodParameterOutputOption.value = typedoc.options.getValue(this.classDiagramMethodParameterOutputOption.name);
        this.classDiagramHideEmptyMembersOption.value = typedoc.options.getValue(this.classDiagramHideEmptyMembersOption.name);
        this.classDiagramTopDownLayoutMaxSiblingsOption.value = typedoc.options.getValue(this.classDiagramTopDownLayoutMaxSiblingsOption.name);
        this.classDiagramMemberVisibilityStyleOption.value = typedoc.options.getValue(this.classDiagramMemberVisibilityStyleOption.name);
        this.classDiagramHideCircledCharOption.value = typedoc.options.getValue(this.classDiagramHideCircledCharOption.name);
        this.classDiagramHideShadowOption.value = typedoc.options.getValue(this.classDiagramHideShadowOption.name);
        this.classDiagramBoxBackgroundColorOption.value = typedoc.options.getValue(this.classDiagramBoxBackgroundColorOption.name);
        this.classDiagramBoxBorderColorOption.value = typedoc.options.getValue(this.classDiagramBoxBorderColorOption.name);
        this.classDiagramBoxBorderRadiusOption.value = typedoc.options.getValue(this.classDiagramBoxBorderRadiusOption.name);
        this.classDiagramBoxBorderWidthOption.value = typedoc.options.getValue(this.classDiagramBoxBorderWidthOption.name);
        this.classDiagramArrowColorOption.value = typedoc.options.getValue(this.classDiagramArrowColorOption.name);
        this.classDiagramClassFontNameOption.value = typedoc.options.getValue(this.classDiagramClassFontNameOption.name);
        this.classDiagramClassFontSizeOption.value = typedoc.options.getValue(this.classDiagramClassFontSizeOption.name);
        this.classDiagramClassFontStyleOption.value = typedoc.options.getValue(this.classDiagramClassFontStyleOption.name);
        this.classDiagramClassFontColorOption.value = typedoc.options.getValue(this.classDiagramClassFontColorOption.name);
        this.classDiagramClassAttributeFontNameOption.value = typedoc.options.getValue(this.classDiagramClassAttributeFontNameOption.name);
        this.classDiagramClassAttributeFontSizeOption.value = typedoc.options.getValue(this.classDiagramClassAttributeFontSizeOption.name);
        this.classDiagramClassAttributeFontStyleOption.value = typedoc.options.getValue(this.classDiagramClassAttributeFontStyleOption.name);
        this.classDiagramClassAttributeFontColorOption.value = typedoc.options.getValue(this.classDiagramClassAttributeFontColorOption.name);
        this.hideProgressBarOption.value = typedoc.options.getValue(this.hideProgressBarOption.name);
        this.createPlantUmlFilesOption.value = typedoc.options.getValue(this.createPlantUmlFilesOption.name);
        this.createVerboseOutputOption.value = typedoc.options.getValue(this.createVerboseOutputOption.name);
    };
    Object.defineProperty(PluginOptions.prototype, "classDiagramType", {
        /**
         * Returns how detailed the generated class diagrams should be.
         * @returns How detailed the generated class diagrams should be.
         */
        get: function () {
            return this.classDiagramTypeOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "outputImageLocation", {
        /**
         * Returns the location where the class diagrams should be stored.
         * @returns The location where the class diagrams should be stored.
         */
        get: function () {
            return this.outputImageLocationOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "outputImageFormat", {
        /**
         * Returns the image format used for the class diagrams.
         * @returns The image format used for the class diagrams.
         */
        get: function () {
            return this.outputImageFormatOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "sectionTitle", {
        /**
         * Returns the title that should be used for the section that contains the class diagrams.
         * @returns The title that should be used for the section that contains the class diagrams.
         */
        get: function () {
            return this.sectionTitleOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramPosition", {
        /**
         * Returns where on the page the class diagrams should be put.
         * @returns Where on the page the class diagrams should be put.
         */
        get: function () {
            return this.classDiagramPositionOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramMethodParameterOutput", {
        /**
         * Returns how method parameters should be output in the class diagrams.
         * @returns How method parameters should be output in the class diagrams.
         */
        get: function () {
            return this.classDiagramMethodParameterOutputOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramHideEmptyMembers", {
        /**
         * Returns whether to hide empty properties and methods in the class diagrams.
         * @returns Whether to hide empty properties and methods in the class diagrams.
         */
        get: function () {
            return this.classDiagramHideEmptyMembersOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramTopDownLayoutMaxSiblings", {
        /**
         * Returns the boundary before swiching from top->down to left->right direction for class diagrams.
         * @returns The boundary before swiching from top->down to left->right direction for class diagrams.
         */
        get: function () {
            return this.classDiagramTopDownLayoutMaxSiblingsOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramMemberVisibilityStyle", {
        /**
         * Returns how the member visibility is rendered in the class diagrams.
         * @returns How the member visibility is rendered in the class diagrams.
         */
        get: function () {
            return this.classDiagramMemberVisibilityStyleOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramHideCircledChar", {
        /**
         * Returns whether to hide the circled character in front of class names for class diagrams.
         * @returns Whether to hide the circled character in front of class names for class diagrams.
         */
        get: function () {
            return this.classDiagramHideCircledCharOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramHideShadow", {
        /**
         * Returns whether to hide the shadows in the class diagrams.
         * @returns Whether to hide the shadows in the class diagrams.
         */
        get: function () {
            return this.classDiagramHideShadowOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramBoxBackgroundColor", {
        /**
         * Returns the background color that should be used for boxes in the class diagrams.
         * @returns The background color that should be used for boxes in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.classDiagramBoxBackgroundColorOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramBoxBorderColor", {
        /**
         * Returns the border color that should be used for boxes in the class diagrams.
         * @returns The border color that should be used for boxes in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.classDiagramBoxBorderColorOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramBoxBorderRadius", {
        /**
         * Returns the border radius that should be used for boxes in the class diagrams.
         * @returns The border radius that should be used for boxes in the class diagrams.
         */
        get: function () {
            return this.classDiagramBoxBorderRadiusOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramBoxBorderWidth", {
        /**
         * Returns the border width that should be used for boxes in the class diagrams.
         * @returns The border width that should be used for boxes in the class diagrams.
         *          The value -1 if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.classDiagramBoxBorderWidthOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramArrowColor", {
        /**
         * Returns the color that should be used for arrows in the class diagrams.
         * @returns The color that should be used for arrows in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.classDiagramArrowColorOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramClassFontName", {
        /**
         * Returns the name of the font that should be used for the class name in the class diagrams.
         * @returns The name of the font that should be used for the class name in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.classDiagramClassFontNameOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramClassFontSize", {
        /**
         * Returns the font size that should be used for class names in the class diagrams.
         * @returns The font size that should be used for class names in the class diagrams.
         *          The value 0 if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.classDiagramClassFontSizeOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramClassFontStyle", {
        /**
         * Returns the font style that should be used for the class name in the class diagrams.
         * @returns The font style that should be used for the class name in the class diagrams.
         */
        get: function () {
            return this.classDiagramClassFontStyleOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramClassFontColor", {
        /**
         * Returns the font color that should be used for the class name in the class diagrams.
         * @returns The font color that should be used for the class name in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.classDiagramClassFontColorOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramClassAttributeFontName", {
        /**
         * Returns the name of the font that should be used for class attributes in the class diagrams.
         * @returns The name of the font that should be used for class attributes in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.classDiagramClassAttributeFontNameOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramClassAttributeFontSize", {
        /**
         * Returns the font size that should be used for class attributes in the class diagrams.
         * @returns The font size that should be used for class attributes in the class diagrams.
         *          The value 0 if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.classDiagramClassAttributeFontSizeOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramClassAttributeFontStyle", {
        /**
         * Returns the font style that should be used for the class attributes in the class diagrams.
         * @returns The font style that should be used for the class attributes in the class diagrams.
         */
        get: function () {
            return this.classDiagramClassAttributeFontStyleOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "classDiagramClassAttributeFontColor", {
        /**
         * Returns the font color that should be used for the class attributes in the class diagrams.
         * @returns The font color that should be used for the class attributes in the class diagrams.
         *          An empty string if no value was specified by the caller.
         *          In this case the PlantUML default value should be used.
         */
        get: function () {
            return this.classDiagramClassAttributeFontColorOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "hideProgressBar", {
        /**
         * Returns whether to hide the progress bar while generating the class diagrams.
         * @returns True, if the progress bar should not be displayed while generating the class diagrams, otherwise false.
         */
        get: function () {
            return this.hideProgressBarOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "createPlantUmlFiles", {
        /**
         * Returns whether to create files containing the PlantUML code for the class diagrams.
         * @returns True, if files with the PlantUML code should be created, otherwise false.
         */
        get: function () {
            return this.createPlantUmlFilesOption.value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PluginOptions.prototype, "createVerboseOutput", {
        /**
         * Returns whether the plugin should output verbose info during its work.
         * @returns True, if plugin should create verbose output, otherwise false.
         */
        get: function () {
            return this.createVerboseOutputOption.value;
        },
        enumerable: true,
        configurable: true
    });
    return PluginOptions;
}());
exports.PluginOptions = PluginOptions;
